Django Categories v|version| documentation! — Django Categories v0.4.8 documentation

Django Categories v0.4.8 documentation

# Django Categories v|version| documentation!

- Table of Contents
- index
  next

# Django Categories v|version| documentation!

Contents:

- Getting Started
  - Connecting your model with Django-Categories
- Using categories in templates
  - Filters
- Registering Models
  - Registering a many-to-one relationship
  - Registering a many-to-many relationship
- Template Tags
  - get_top_level_categories
  - display_path_as_ul
  - get_category_drilldown
  - display_drilldown_as_ul
  - breadcrumbs tag

## Indices and tables

- Index
- Module Index
- Search Page